@@ -394,12 +394,24 @@ class GeneralGroup(ArgumentGroup):
             The endpoints are used in the formation of a connection\
             with another agent.",
         )
+        parser.add_argument(
+            "--profile-endpoint",
+            type=str,
+            metavar="<profile_endpoint>",
+            help="Specifies the profile endpoint for the (public) DID.",
+        )
         parser.add_argument(
             "--read-only-ledger",
             action="store_true",
             help="Sets ledger to read-only to prevent updates.\
             Default: false.",
         )
+        parser.add_argument(
+            "--tails-server-base-url",
+            type=str,
+            metavar="<tails-server-base-url>",
+            help="Sets the base url of the tails server in use.",
+        )
 
     def get_settings(self, args: Namespace) -> dict:
         """Extract general settings."""
@@ -407,12 +419,16 @@ class GeneralGroup(ArgumentGroup):
         if args.external_plugins:
             settings["external_plugins"] = args.external_plugins
         if args.storage_type:
-            settings["storage.type"] = args.storage_type
+            settings["storage_type"] = args.storage_type
         if args.endpoint:
             settings["default_endpoint"] = args.endpoint[0]
             settings["additional_endpoints"] = args.endpoint[1:]
+        if args.profile_endpoint:
+            settings["profile_endpoint"] = args.profile_endpoint
         if args.read_only_ledger:
             settings["read_only_ledger"] = True
+        if args.tails_server_base_url:
+            settings["tails_server_base_url"] = args.tails_server_base_url
         return settings
 
 
