@@ -13,6 +13,7 @@ from ..ledger.provider import LedgerProvider
 from ..issuer.base import BaseIssuer
 from ..holder.base import BaseHolder
 from ..verifier.base import BaseVerifier
+from ..tails.base import BaseTailsServer
 
 from ..protocols.actionmenu.v1_0.base_service import BaseMenuService
 from ..protocols.actionmenu.v1_0.driver_service import DriverMenuService
@@ -119,6 +120,10 @@ class DefaultContextBuilder(ContextBuilder):
                 ClassProvider.Inject(BaseLedger),
             ),
         )
+        context.injector.bind_provider(
+            BaseTailsServer,
+            ClassProvider("aries_cloudagent.tails.indy_tails_server.IndyTailsServer",),
+        )
 
         # Register default pack format
         context.injector.bind_provider(
