@@ -2,7 +2,7 @@
 
 from typing import Sequence
 
-from marshmallow import fields
+from marshmallow import EXCLUDE, fields
 
 from ..models.base import BaseModel, BaseModelSchema
 
@@ -44,6 +44,7 @@ class LocalizationDecoratorSchema(BaseModelSchema):
         """LocalizationDecoratorSchema metadata."""
 
         model_class = LocalizationDecorator
+        unknown = EXCLUDE
 
     locale = fields.Str(required=True, description="Locale specifier", example="en-CA",)
     localizable = fields.List(
