@@ -4,7 +4,7 @@ The transport decorator (~transport).
 This decorator allows changes to agent response behaviour and queue status updates.
 """
 
-from marshmallow import fields, validate
+from marshmallow import EXCLUDE, fields, validate
 
 from ..models.base import BaseModel, BaseModelSchema
 from ..valid import UUIDFour, WHOLE_NUM
@@ -46,6 +46,7 @@ class TransportDecoratorSchema(BaseModelSchema):
         """TransportDecoratorSchema metadata."""
 
         model_class = TransportDecorator
+        unknown = EXCLUDE
 
     return_route = fields.Str(
         required=False,
