@@ -1,7 +1,7 @@
 """Represents a connection problem report message."""
 
 from enum import Enum
-from marshmallow import fields, validate
+from marshmallow import EXCLUDE, fields, validate
 
 from .....messaging.agent_message import AgentMessage, AgentMessageSchema
 
@@ -50,6 +50,7 @@ class ProblemReportSchema(AgentMessageSchema):
         """Metadata for problem report schema."""
 
         model_class = ProblemReport
+        unknown = EXCLUDE
 
     explain = fields.Str(
         required=False,
