@@ -1,3 +1,4 @@
+import asyncio
 import json
 
 from asynctest import TestCase as AsyncTestCase
@@ -885,6 +886,10 @@ class TestCredentialManager(AsyncTestCase):
         with async_mock.patch.object(
             test_module, "IssuerRevRegRecord", autospec=True
         ) as issuer_rr_rec, async_mock.patch.object(
+            test_module, "IndyRevocation", autospec=True
+        ) as revoc, async_mock.patch.object(
+            asyncio, "ensure_future", autospec=True
+        ) as asyncio_mock, async_mock.patch.object(
             V10CredentialExchange, "save", autospec=True
         ) as save_ex:
             issuer_rr_rec.query_by_cred_def_id = async_mock.CoroutineMock(
@@ -897,11 +902,13 @@ class TestCredentialManager(AsyncTestCase):
                         ),
                         mark_full=async_mock.CoroutineMock(),
                         revoc_reg_id=REV_REG_ID,
+                        save=async_mock.CoroutineMock(),
+                        publish_registry_entry=async_mock.CoroutineMock(),
                     )
                 ]
             )
             (ret_exchange, ret_cred_issue) = await self.manager.issue_credential(
-                stored_exchange, comment=comment
+                stored_exchange, comment=comment, retries=1
             )
 
             save_ex.assert_called_once()
@@ -921,7 +928,9 @@ class TestCredentialManager(AsyncTestCase):
             (
                 ret_existing_exchange,
                 ret_existing_cred,
-            ) = await self.manager.issue_credential(stored_exchange, comment=comment)
+            ) = await self.manager.issue_credential(
+                stored_exchange, comment=comment, retries=0
+            )
             assert ret_existing_exchange == ret_exchange
             assert ret_existing_cred._thread_id == thread_id
 
@@ -975,7 +984,7 @@ class TestCredentialManager(AsyncTestCase):
             V10CredentialExchange, "save", autospec=True
         ) as save_ex:
             (ret_exchange, ret_cred_issue) = await self.manager.issue_credential(
-                stored_exchange, comment=comment
+                stored_exchange, comment=comment, retries=0
             )
 
             save_ex.assert_called_once()
@@ -1053,7 +1062,9 @@ class TestCredentialManager(AsyncTestCase):
                 return_value=[]
             )
             with self.assertRaises(CredentialManagerError) as x_cred_mgr:
-                await self.manager.issue_credential(stored_exchange, comment=comment)
+                await self.manager.issue_credential(
+                    stored_exchange, comment=comment, retries=0
+                )
                 assert "has no active revocation registry" in x_cred_mgr.message
 
     async def test_issue_credential_rr_full(self):
@@ -1108,7 +1119,109 @@ class TestCredentialManager(AsyncTestCase):
             )
 
             with self.assertRaises(test_module.IssuerRevocationRegistryFullError):
-                await self.manager.issue_credential(stored_exchange, comment=comment)
+                await self.manager.issue_credential(
+                    stored_exchange, comment=comment, retries=0
+                )
+
+    async def test_issue_credential_rr_full_rr_staged_retry(self):
+        connection_id = "test_conn_id"
+        comment = "comment"
+        cred_values = {"attr": "value"}
+        indy_offer = {"schema_id": SCHEMA_ID, "cred_def_id": CRED_DEF_ID, "nonce": "0"}
+        indy_cred_req = {"schema_id": SCHEMA_ID, "cred_def_id": CRED_DEF_ID}
+        thread_id = "thread-id"
+        revocation_id = 1
+
+        stored_exchange = V10CredentialExchange(
+            credential_exchange_id="dummy-cxid",
+            connection_id=connection_id,
+            credential_definition_id=CRED_DEF_ID,
+            credential_offer=indy_offer,
+            credential_request=indy_cred_req,
+            credential_proposal_dict=CredentialProposal(
+                credential_proposal=CredentialPreview.deserialize(
+                    {"attributes": [{"name": "attr", "value": "value"}]}
+                ),
+                cred_def_id=CRED_DEF_ID,
+                schema_id=SCHEMA_ID,
+            ).serialize(),
+            initiator=V10CredentialExchange.INITIATOR_SELF,
+            role=V10CredentialExchange.ROLE_ISSUER,
+            state=V10CredentialExchange.STATE_REQUEST_RECEIVED,
+            thread_id=thread_id,
+            revocation_id=revocation_id,
+        )
+
+        stored_exchange.save = async_mock.CoroutineMock()
+
+        issuer = async_mock.MagicMock()
+        cred = {"indy": "credential"}
+        cred_rev_id = "1"
+        issuer.create_credential = async_mock.CoroutineMock(
+            side_effect=[
+                test_module.IssuerRevocationRegistryFullError("it's full"),
+                (json.dumps({"good": "credential"}), str(revocation_id)),
+            ]
+        )
+        self.context.injector.bind_instance(BaseIssuer, issuer)
+
+        active_full_reg = [
+            async_mock.MagicMock(
+                get_registry=async_mock.CoroutineMock(
+                    return_value=async_mock.MagicMock(
+                        tails_local_path="dummy-path", max_creds=revocation_id
+                    )
+                ),
+                revoc_reg_id=REV_REG_ID,
+                mark_full=async_mock.CoroutineMock(),
+            )
+        ]
+
+        active_non_full_reg = [
+            async_mock.MagicMock(
+                get_registry=async_mock.CoroutineMock(
+                    return_value=async_mock.MagicMock(
+                        tails_local_path="dummy-path", max_creds=1000
+                    )
+                ),
+                revoc_reg_id=REV_REG_ID,
+                mark_full=async_mock.CoroutineMock(),
+            )
+        ]
+
+        pending_reg = [
+            async_mock.MagicMock(
+                get_registry=async_mock.CoroutineMock(
+                    return_value=async_mock.MagicMock(tails_local_path="dummy-path")
+                ),
+                revoc_reg_id=REV_REG_ID,
+                mark_full=async_mock.CoroutineMock(),
+                state="published",
+                save=async_mock.CoroutineMock(),
+                publish_registry_entry=async_mock.CoroutineMock(),
+            )
+        ]
+
+        with async_mock.patch.object(
+            test_module, "IssuerRevRegRecord", autospec=True
+        ) as issuer_rr_rec, async_mock.patch.object(
+            test_module, "IndyRevocation", autospec=True
+        ) as revoc, async_mock.patch.object(
+            asyncio, "ensure_future", autospec=True
+        ) as asyncio_mock:
+            issuer_rr_rec.query_by_cred_def_id.side_effect = [
+                [],  # First call checking for staged registries
+                active_full_reg,  # Get active full registry
+                [],  # Get active full registry after rev-reg-full
+                [],  # Get staged
+                pending_reg,  # Get published
+                [],  # Get staged, on retry pass
+                active_non_full_reg,  # Get active
+            ]
+
+            await self.manager.issue_credential(
+                stored_exchange, comment=comment, retries=1
+            )
 
     async def test_receive_credential(self):
         connection_id = "test_conn_id"
