@@ -5,9 +5,10 @@ import logging
 
 from aiohttp import web
 from aiohttp_apispec import docs, request_schema
-from marshmallow import fields, Schema
+from marshmallow import fields
 from marshmallow.exceptions import ValidationError
 
+from ....messaging.models.openapi import OpenAPISchema
 from ....storage.error import StorageNotFoundError
 
 from .manager import OutOfBandManager, OutOfBandManagerError
@@ -17,10 +18,10 @@ from .messages.invitation import InvitationSchema
 LOGGER = logging.getLogger(__name__)
 
 
-class InvitationCreateRequestSchema(Schema):
+class InvitationCreateRequestSchema(OpenAPISchema):
     """Invitation create request Schema."""
 
-    class AttachmentDefSchema(Schema):
+    class AttachmentDefSchema(OpenAPISchema):
         """Attachment Schema."""
 
         _id = fields.String(data_key="id")
@@ -31,7 +32,7 @@ class InvitationCreateRequestSchema(Schema):
     use_public_did = fields.Boolean(default=False)
 
 
-class InvitationSchema(InvitationSchema):
+class InvitationReceiveRequestSchema(InvitationSchema):
     """Invitation Schema."""
 
     service = fields.Field()
@@ -78,7 +79,7 @@ async def invitation_create(request: web.BaseRequest):
 @docs(
     tags=["out-of-band"], summary="Create a new connection invitation",
 )
-@request_schema(InvitationSchema())
+@request_schema(InvitationReceiveRequestSchema())
 async def invitation_receive(request: web.BaseRequest):
     """
     Request handler for creating a new connection invitation.
