@@ -1,9 +1,10 @@
 """Represents an explicit RFC 15 ack message, adopted into present-proof protocol."""
 
+from marshmallow import EXCLUDE
+
 from .....messaging.ack.message import Ack, AckSchema
 from ..message_types import PRESENTATION_ACK, PROTOCOL_PACKAGE
 
-
 HANDLER_CLASS = (
     f"{PROTOCOL_PACKAGE}.handlers.presentation_ack_handler.PresentationAckHandler"
 )
@@ -37,3 +38,4 @@ class PresentationAckSchema(AckSchema):
         """PresentationAck schema metadata."""
 
         model_class = PresentationAck
+        unknown = EXCLUDE
