@@ -1,5 +1,9 @@
 """Message type identifiers for problem reports."""
 
+SPEC_URI = (
+    "https://github.com/hyperledger/aries-rfcs/tree/"
+    "89d14c15ab35b667e7a9d04fe42d4d48b10468cf/features/0035-report-problem"
+)
 PROTOCOL_URI = "did:sov:BzCbsNYhMrjHiqZDTUASHg;spec/notification/1.0"
 
 PROBLEM_REPORT = f"{PROTOCOL_URI}/problem-report"
