@@ -1,6 +1,6 @@
 """Handler for incoming route-query-request messages."""
 
-from aries_cloudagent.messaging.base_handler import (
+from .....messaging.base_handler import (
     BaseHandler,
     BaseResponder,
     HandlerException,
@@ -25,8 +25,6 @@ class RouteQueryRequestHandler(BaseHandler):
         if not context.connection_ready:
             raise HandlerException("Cannot query routes: no active connection")
 
-        # TODO implement pagination
-
         mgr = RoutingManager(context)
         result = await mgr.get_routes(
             context.connection_record.connection_id, context.message.filter
