@@ -141,7 +141,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
 
         with async_mock.patch.object(
             test_module, "IndyRevocation", autospec=True
@@ -166,7 +166,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
 
         with async_mock.patch.object(
             test_module, "IndyRevocation", autospec=True
@@ -233,7 +233,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
 
         with async_mock.patch.object(
             test_module, "IndyRevocation", autospec=True
@@ -256,7 +256,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
 
         with async_mock.patch.object(
             test_module, "IndyRevocation", autospec=True
@@ -279,7 +279,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
 
         with async_mock.patch.object(
             test_module, "IndyRevocation", autospec=True
@@ -306,7 +306,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
 
         with async_mock.patch.object(
             test_module, "IndyRevocation", autospec=True
@@ -323,13 +323,37 @@ class TestRevocationRoutes(AsyncTestCase):
                 result = await test_module.publish_registry(request)
             mock_json_response.assert_not_called()
 
+    async def test_publish_registry_x(self):
+        REV_REG_ID = "{}:4:{}:3:CL:1234:default:CL_ACCUM:default".format(
+            self.test_did, self.test_did
+        )
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.match_info = {"rev_reg_id": REV_REG_ID}
+
+        with async_mock.patch.object(
+            test_module, "IndyRevocation", autospec=True
+        ) as mock_indy_revoc:
+            mock_indy_revoc.return_value = async_mock.MagicMock(
+                get_issuer_rev_reg_record=async_mock.CoroutineMock(
+                    return_value=async_mock.MagicMock(
+                        publish_registry_definition=async_mock.CoroutineMock(
+                            side_effect=test_module.RevocationError()
+                        ),
+                    )
+                )
+            )
+
+            with self.assertRaises(test_module.web.HTTPBadRequest):
+                await test_module.publish_registry(request)
+
     async def test_update_registry(self):
         REV_REG_ID = "{}:4:{}:3:CL:1234:default:CL_ACCUM:default".format(
             self.test_did, self.test_did
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
         request.json = async_mock.CoroutineMock(
             return_value={
                 "tails_public_uri": f"http://sample.ca:8181/tails/{REV_REG_ID}"
@@ -361,7 +385,7 @@ class TestRevocationRoutes(AsyncTestCase):
         )
         request = async_mock.MagicMock()
         request.app = self.app
-        request.match_info = {"id": REV_REG_ID}
+        request.match_info = {"rev_reg_id": REV_REG_ID}
         request.json = async_mock.CoroutineMock(
             return_value={
                 "tails_public_uri": f"http://sample.ca:8181/tails/{REV_REG_ID}"
@@ -383,9 +407,57 @@ class TestRevocationRoutes(AsyncTestCase):
                 result = await test_module.update_registry(request)
             mock_json_response.assert_not_called()
 
+    async def test_update_registry_x(self):
+        REV_REG_ID = "{}:4:{}:3:CL:1234:default:CL_ACCUM:default".format(
+            self.test_did, self.test_did
+        )
+        request = async_mock.MagicMock()
+        request.app = self.app
+        request.match_info = {"rev_reg_id": REV_REG_ID}
+        request.json = async_mock.CoroutineMock(
+            return_value={
+                "tails_public_uri": f"http://sample.ca:8181/tails/{REV_REG_ID}"
+            }
+        )
+
+        with async_mock.patch.object(
+            test_module, "IndyRevocation", autospec=True
+        ) as mock_indy_revoc:
+            mock_indy_revoc.return_value = async_mock.MagicMock(
+                get_issuer_rev_reg_record=async_mock.CoroutineMock(
+                    return_value=async_mock.MagicMock(
+                        set_tails_file_public_uri=async_mock.CoroutineMock(
+                            side_effect=test_module.RevocationError()
+                        ),
+                    )
+                )
+            )
+
+            with self.assertRaises(test_module.web.HTTPBadRequest):
+                await test_module.update_registry(request)
+
     async def test_register(self):
         mock_app = async_mock.MagicMock()
         mock_app.add_routes = async_mock.MagicMock()
 
         await test_module.register(mock_app)
         mock_app.add_routes.assert_called_once()
+
+    async def test_post_process_routes(self):
+        mock_app = async_mock.MagicMock(
+            _state={
+                "swagger_dict": {
+                    "paths": {
+                        "/revocation/registry/{rev_reg_id}/tails-file": {
+                            "get": {"responses": {"200": {"description": "tails file"}}}
+                        }
+                    }
+                }
+            }
+        )
+        test_module.post_process_routes(mock_app)
+        assert mock_app._state["swagger_dict"]["paths"][
+            "/revocation/registry/{rev_reg_id}/tails-file"
+        ]["get"]["responses"]["200"]["schema"] == {"type": "string", "format": "binary"}
+
+        assert "tags" in mock_app._state["swagger_dict"]
